@@ -57,6 +57,9 @@ MainWindow::MainWindow(
 {
   ui->setupUi(this);
 
+  ui->pauseButton->setEnabled(false);
+  ui->stopButton->setEnabled(false);
+
   updateStatus(Idle_Status);
 
   setAttribute(Qt::WA_Maemo5StackedWindow);
@@ -466,6 +469,9 @@ void MainWindow::on_recordButton_clicked()
       e.display();
     }
   }
+
+  ui->pauseButton->setEnabled(true);
+  ui->stopButton->setEnabled(true);
 }
 
 
@@ -485,6 +491,9 @@ void MainWindow::on_playButton_clicked()
   filenameToPlay = filename;
 
   myDBus->requestToPlay();
+
+  ui->pauseButton->setEnabled(true);
+  ui->stopButton->setEnabled(true);
 }
 
 
@@ -521,6 +530,9 @@ void MainWindow::on_stopButton_clicked()
   {
     e.display();
   }
+
+  ui->pauseButton->setEnabled(false);
+  ui->stopButton->setEnabled(false);
 }
 
 
