@@ -723,11 +723,12 @@ void OreGst::startRecording(
       {
         g_object_set(G_OBJECT(microphoneSource), "device", "source.hw1", NULL);
         g_object_set(
-          G_OBJECT(microphoneSource), "device", "sink.hw1.monitor", NULL);
+          G_OBJECT(speakerSource), "device", "sink.hw1.monitor", NULL);
       }
       else
       {
-        g_object_set(G_OBJECT(speakerSource), "device", "source.voice", NULL);
+        g_object_set(
+          G_OBJECT(microphoneSource), "device", "source.voice", NULL);
         g_object_set(
           G_OBJECT(speakerSource), "device", "sink.hw0.monitor", NULL);
       }
@@ -1061,6 +1062,7 @@ void OreGst::startPlaying(
   // Construct a URI:
   QString uriFilename = "file://";
   uriFilename += filename;
+qDebug() << "playing file from: " << filename;
   QByteArray ba = uriFilename.toAscii();
   g_object_set(
     G_OBJECT(player),
